@@ -1,4 +1,4 @@
-BEGIN { $| = 1; print "1..3\n"; }
+BEGIN { $| = 1; print "1..4\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use B::Generate;
 $loaded = 1;
@@ -29,3 +29,6 @@ my $b; # STAY STILL!
 
 $a = 17; $b = 15; print "ok ", $a + $b, "\n";
 $c = 30; $d = 10; print "ok ", $c - $d, "\n";
+
+my $newop = B::BINOP->new("add", 0, undef, undef); # This used to segv
+print "ok 4\n";
